@@ -17,6 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
+#include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/AppInfo.h>
@@ -25,7 +26,6 @@
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 #include <Lum/Dlg/About.h>
 
@@ -53,29 +53,17 @@ public:
   {
     gameArea=new GameArea();
 
-    AttachModel(restartGameAction);
-    AttachModel(aboutAction);
-    AttachModel(GetOpenedAction());
-    AttachModel(GetClosedAction());
-  }
-
-  ~MainDialog()
-  {
-    UnattachModel(GetClosedAction());
-    UnattachModel(GetOpenedAction());
-    UnattachModel(aboutAction);
-    UnattachModel(restartGameAction);
+    Observe(restartGameAction);
+    Observe(aboutAction);
+    Observe(GetOpenedAction());
+    Observe(GetClosedAction());
   }
 
   void PreInit()
   {
-    Lum::Button      *button;
-    Lum::Panel       *horiz,*vert;
-    Lum::WindowGroup *wGroup;
-    Control          *control;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
+    Lum::Button *button;
+    Lum::Panel  *horiz,*vert;
+    Control     *control;
 
     horiz=new Lum::HPanel();
     horiz->SetFlex(true,true);
@@ -97,19 +85,21 @@ public:
     button->SetText(L"_Restart Game");
     vert->Add(button);
 
-    vert->Add(new Lum::VSpace());
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(aboutAction);
-    button->SetText(L"_About");
-    vert->Add(button);
-
     horiz->Add(vert);
 
-    wGroup->SetMain(horiz);
+    SetMain(horiz);
 
-    SetTop(wGroup);
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
+
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
